@@ -29,7 +29,7 @@ from infrahub.core.utils import add_relationship, convert_ip_to_binary_str, upda
 from infrahub.exceptions import ValidationError
 from infrahub.helpers import hash_password
 
-from ..types import ATTRIBUTE_TYPES, LARGE_ATTRIBUTE_TYPES
+from ..types import is_large_attribute_type
 from .constants.relationship_label import RELATIONSHIP_TO_NODE_LABEL, RELATIONSHIP_TO_VALUE_LABEL
 from .schema.attribute_parameters import NumberAttributeParameters
 
@@ -72,7 +72,6 @@ class AttributeCreateData(BaseModel):
     is_visible: bool
     source_prop: list[NodePropertyData] = Field(default_factory=list)
     owner_prop: list[NodePropertyData] = Field(default_factory=list)
-    node_type: AttributeDBNodeType = AttributeDBNodeType.DEFAULT
 
 
 class BaseAttribute(FlagPropertyMixin, NodePropertyMixin):
@@ -278,7 +277,7 @@ class BaseAttribute(FlagPropertyMixin, NodePropertyMixin):
             data["value"] = NULL_VALUE
         else:
             serialized_value = self.serialize_value()
-            if isinstance(serialized_value, str) and ATTRIBUTE_TYPES[self.schema.kind] not in LARGE_ATTRIBUTE_TYPES:
+            if isinstance(serialized_value, str) and not is_large_attribute_type(self.schema.kind):
                 # Perform validation here to avoid an extra serialization during validation step.
                 # Standard non-str attributes (integer, boolean) do not exceed limit size related to neo4j indexing.
                 validate_string_length(serialized_value)
@@ -497,6 +496,8 @@ class BaseAttribute(FlagPropertyMixin, NodePropertyMixin):
         if changelog.has_updates:
             return changelog
 
+        return None
+
     async def to_graphql(
         self,
         db: InfrahubDatabase,
@@ -622,7 +623,9 @@ class BaseAttribute(FlagPropertyMixin, NodePropertyMixin):
         return changed
 
     def get_db_node_type(self) -> AttributeDBNodeType:
-        return AttributeDBNodeType.DEFAULT
+        if is_large_attribute_type(self.get_kind()):
+            return AttributeDBNodeType.DEFAULT
+        return AttributeDBNodeType.INDEXED
 
     def get_create_data(self) -> AttributeCreateData:
         branch = self.branch
@@ -633,7 +636,6 @@ class BaseAttribute(FlagPropertyMixin, NodePropertyMixin):
             branch = registry.get_global_branch()
             hierarchy_level = 0
         data = AttributeCreateData(
-            node_type=self.get_db_node_type(),
             uuid=str(UUIDT()),
             name=self.name,
             type=self.get_kind(),
@@ -678,6 +680,12 @@ class String(BaseAttribute):
     type = str
     value: str
 
+    @classmethod
+    def validate_content(cls, value: Any, name: str, schema: AttributeSchema) -> None:
+        if value is not None and not is_large_attribute_type(schema.kind):
+            validate_string_length(value=str(value))
+        super().validate_content(value=value, name=name, schema=schema)
+
 
 class StringOptional(String):
     value: str | None
@@ -944,7 +952,7 @@ class IPNetwork(BaseAttribute):
     def get_db_node_type(self) -> AttributeDBNodeType:
         if self.value is not None:
             return AttributeDBNodeType.IPNETWORK
-        return AttributeDBNodeType.DEFAULT
+        return super().get_db_node_type()
 
     def to_db(self) -> dict[str, Any]:
         data = super().to_db()
@@ -1080,7 +1088,7 @@ class IPHost(BaseAttribute):
     def get_db_node_type(self) -> AttributeDBNodeType:
         if self.value is not None:
             return AttributeDBNodeType.IPHOST
-        return AttributeDBNodeType.DEFAULT
+        return super().get_db_node_type()
 
     def to_db(self) -> dict[str, Any]:
         data = super().to_db()
