@@ -16,7 +16,7 @@ class Migration001Query01(Query):
     name = "migration_001_01"
     type: QueryType = QueryType.WRITE
 
-    async def query_init(self, db: InfrahubDatabase, **kwargs: dict[str, Any]) -> None:
+    async def query_init(self, db: InfrahubDatabase, **kwargs: dict[str, Any]) -> None:  # noqa: ARG002
         query = """
         MATCH (root:Root)
         SET root.graph_version = 1
