@@ -6,7 +6,8 @@ from infrahub_sdk.utils import compare_lists
 
 from infrahub.core.constants import PathType
 from infrahub.core.path import DataPath, GroupedDataPaths
-from infrahub.core.schema import NodeSchema
+from infrahub.core.schema import MainSchemaTypes, NodeSchema
+from infrahub.exceptions import SchemaNotFoundError
 
 from ..interface import ConstraintCheckerInterface
 
@@ -41,8 +42,29 @@ class NodeInheritFromChecker(ConstraintCheckerInterface):
             return grouped_data_paths_list
 
         _, removed, _ = compare_lists(list1=current_schema.inherit_from, list2=request.node_schema.inherit_from)
+        current_inherit_from_ids = {
+            g.id: g.kind
+            for g in [
+                self.db.schema.get(name=n, branch=request.branch, duplicate=False) for n in current_schema.inherit_from
+            ]
+        }
 
-        if removed:
+        # Gather IDs for each inherited node in use for candidate schema
+        request_inherited: list[MainSchemaTypes] = []
+        for n in request.node_schema.inherit_from:
+            try:
+                schema = request.schema_branch.get(name=n, duplicate=False)
+            except SchemaNotFoundError:
+                schema = self.db.schema.get(name=n, branch=request.branch, duplicate=False)
+            request_inherited.append(schema)
+        request_inherit_from_ids = {g.id: g.kind for g in request_inherited}
+
+        # Compare IDs to find out if some inherited nodes were removed
+        # Comparing IDs helps us in understanding if a node was renamed or really removed
+        _, removed_ids, _ = compare_lists(
+            list1=list(current_inherit_from_ids.keys()), list2=list(request_inherit_from_ids.keys())
+        )
+        if removed := [current_inherit_from_ids[k] for k in removed_ids]:
             group_data_path.add_data_path(
                 DataPath(
                     branch=str(request.branch.name),
