@@ -1,21 +1,21 @@
 from prefect import flow
 
 from infrahub.exceptions import RepositoryError
-from infrahub.git.repository import InfrahubRepository, get_initialized_repo, initialize_repo
+from infrahub.git.repository import InfrahubRepository, get_initialized_repo
 from infrahub.log import get_logger
 from infrahub.message_bus import messages
 from infrahub.message_bus.messages.git_repository_connectivity import (
     GitRepositoryConnectivityResponse,
     GitRepositoryConnectivityResponseData,
 )
-from infrahub.services import InfrahubServices
 from infrahub.worker import WORKER_IDENTITY
+from infrahub.workers.dependencies import get_client, get_message_bus
 
 log = get_logger()
 
 
 @flow(name="git-repository-check-connectivity", flow_run_name="Check connectivity for {message.repository_name}")
-async def connectivity(message: messages.GitRepositoryConnectivity, service: InfrahubServices) -> None:
+async def connectivity(message: messages.GitRepositoryConnectivity) -> None:
     response_data = GitRepositoryConnectivityResponseData(message="Successfully accessed repository", success=True)
 
     try:
@@ -28,30 +28,22 @@ async def connectivity(message: messages.GitRepositoryConnectivity, service: Inf
         response = GitRepositoryConnectivityResponse(
             data=response_data,
         )
-        await service.message_bus.reply_if_initiator_meta(message=response, initiator=message)
+        message_bus = await get_message_bus()
+        await message_bus.reply_if_initiator_meta(message=response, initiator=message)
 
 
 @flow(name="refresh-git-fetch", flow_run_name="Fetch git repository {message.repository_name} on " + WORKER_IDENTITY)
-async def fetch(message: messages.RefreshGitFetch, service: InfrahubServices) -> None:
+async def fetch(message: messages.RefreshGitFetch) -> None:
     if message.meta and message.meta.initiator_id == WORKER_IDENTITY:
         log.info("Ignoring git fetch request originating from self", worker=WORKER_IDENTITY)
         return
 
-    try:
-        repo = await get_initialized_repo(
-            repository_id=message.repository_id,
-            name=message.repository_name,
-            service=service,
-            repository_kind=message.repository_kind,
-        )
-    except RepositoryError:
-        repo = await initialize_repo(
-            location=message.location,
-            repository_id=message.repository_id,
-            name=message.repository_name,
-            service=service,
-            repository_kind=message.repository_kind,
-        )
+    repo = await get_initialized_repo(
+        client=get_client(),
+        repository_id=message.repository_id,
+        name=message.repository_name,
+        repository_kind=message.repository_kind,
+    )
 
     await repo.fetch()
     await repo.pull(
